@@ -430,7 +430,7 @@ _cb_messagetlvs(struct rfc5444_reader_tlvblock_context *context) {
       _current.mprtypes, sizeof(_current.mprtypes),
       _nhdp_message_tlvs[IDX_TLV_MPRTYPES].tlv);
 
-  /* extract willingness */
+  /* extract willingness into temporary buffers */
   nhdp_domain_process_willingness_tlv(_current.mprtypes, _current.mprtypes_size,
         _nhdp_message_tlvs[IDX_TLV_WILLINGNESS].tlv);
 
@@ -963,6 +963,9 @@ _cb_msg_pass2_end(struct rfc5444_reader_tlvblock_context *context, bool dropped)
   /* overwrite originator of neighbor entry */
   nhdp_db_neighbor_set_originator(_current.neighbor, &context->orig_addr);
 
+  /* copy willingness to permanent storage */
+  nhdp_domain_store_willingness(_current.neighbor);
+
   /* update MPR sets and link metrics */
   nhdp_domain_neighbor_changed(_current.neighbor);
 
