@@ -61,9 +61,20 @@
 /* constants and definitions */
 #define LOG_RFC5444 _oonf_rfc5444_subsystem.logging
 
+/**
+ * RFC5444 configuration
+ */
 struct _rfc5444_config {
+  /*! port number to be used for RFC5444 communication */
   int32_t port;
+
+  /*! IP protocol number to be used for RFC5444 communication */
   int ip_proto;
+
+  /**
+   * interval to wait for aggregating
+   * RFC5444 messages on the same target
+   */
   uint64_t aggregation_interval;
 };
 
@@ -92,10 +103,10 @@ static struct rfc5444_reader_addrblock_entry *_alloc_addrblock_entry(void);
 static struct rfc5444_reader_tlvblock_entry *_alloc_tlvblock_entry(void);
 static struct rfc5444_writer_address *_alloc_address_entry(void);
 static struct rfc5444_writer_addrtlv *_alloc_addrtlv_entry(void);
-static void _free_addrblock_entry(void *);
-static void _free_tlvblock_entry(void *);
-static void _free_address_entry(void *);
-static void _free_addrtlv_entry(void *);
+static void _free_addrblock_entry(struct rfc5444_reader_addrblock_entry* addrblock);
+static void _free_tlvblock_entry(struct rfc5444_reader_tlvblock_entry *tlvblock);
+static void _free_address_entry(struct rfc5444_writer_address *);
+static void _free_addrtlv_entry(struct rfc5444_writer_addrtlv *);
 
 static void _cb_add_seqno(struct rfc5444_writer *, struct rfc5444_writer_target *);
 static void _cb_aggregation_event (void *);
@@ -1109,9 +1120,9 @@ _cb_forward_message(
   protocol = container_of(context->reader, struct oonf_rfc5444_protocol, reader);
 
   /* forward message */
-  OONF_INFO(LOG_RFC5444, "Forwarding message type %u", buffer[0]);
+  OONF_INFO(LOG_RFC5444, "Forwarding message type %u", context->msg_type);
 
-  result = rfc5444_writer_forward_msg(&protocol->writer, buffer, length);
+  result = rfc5444_writer_forward_msg(&protocol->writer, context, buffer, length);
   if (result != RFC5444_OKAY && result != RFC5444_NO_MSGCREATOR) {
     OONF_WARN(LOG_RFC5444, "Error while forwarding message: %s (%d)",
         rfc5444_strerror(result), result);
@@ -1216,7 +1227,7 @@ _alloc_addrtlv_entry(void) {
  * @param pointer to addrblock
  */
 static void
-_free_addrblock_entry(void *addrblock) {
+_free_addrblock_entry(struct rfc5444_reader_addrblock_entry* addrblock) {
   oonf_class_free(&_addrblock_memcookie, addrblock);
 }
 
@@ -1225,7 +1236,7 @@ _free_addrblock_entry(void *addrblock) {
  * @param pointer to tlvblock
  */
 static void
-_free_tlvblock_entry(void *tlvblock) {
+_free_tlvblock_entry(struct rfc5444_reader_tlvblock_entry *tlvblock) {
   oonf_class_free(&_tlvblock_memcookie, tlvblock);
 }
 
@@ -1234,7 +1245,7 @@ _free_tlvblock_entry(void *tlvblock) {
  * @param pointer to tlvblock
  */
 static void
-_free_address_entry(void *address) {
+_free_address_entry(struct rfc5444_writer_address *address) {
   oonf_class_free(&_address_memcookie, address);
 }
 
@@ -1243,7 +1254,7 @@ _free_address_entry(void *address) {
  * @param pointer to tlvblock
  */
 static void
-_free_addrtlv_entry(void *addrtlv) {
+_free_addrtlv_entry(struct rfc5444_writer_addrtlv *addrtlv) {
   oonf_class_free(&_addrtlv_memcookie, addrtlv);
 }
 
